Package: CVD
Type: Package
Title: Color Vision Deficiencies
Version: 1.0.2
Encoding: UTF-8
Authors@R: c(person(given = "Jose", family = "Gama", role = c("aut","cre","trl"),email = "rxprtgama@gmail.com"),
    person(given = "Brian", family = "Foutch", role = "ctb"),
    person(given = "Mark", family = "Grundland", role = "ctb"), 
    person(given = "Neil", family = "Dodgson", role = "ctb"))  
Description: Methods for color vision deficiencies (CVD), to help understanding and mitigating issues with CVDs and to generate tests for diagnosis and interpretation.
License: GPL (>= 3)
Depends: R (>= 2.10)
Enhances: png, gWidgets2, RGtk2
LazyData: yes
Author: Jose Gama [aut, cre, trl],
  Brian Foutch [ctb],
  Mark Grundland [ctb],
  Neil Dodgson [ctb]
Maintainer: Jose Gama <rxprtgama@gmail.com>
Repository: CRAN
Repository/R-Forge/Project: cvd
Repository/R-Forge/Revision: 16
Repository/R-Forge/DateTimeStamp: 2016-11-28 09:01:48
Date/Publication: 2016-11-28 13:23:17
NeedsCompilation: no
Packaged: 2016-11-28 09:06:04 UTC; rforge
Built: R 4.6.0; ; 2026-04-26 15:47:04 UTC; unix
