importFrom("graphics", "Axis", "abline", "legend", "lines", "par", "plot", "segments", "symbols", "text", "title")
importFrom("stats", "end", "lm", "quantile", "rnorm", "runif")
export("plotConfusionVectors",
"loadPNG",
"createPNGbuttons",
"vectorPNGbuttons",
"approx.scotopic.luminance.LarsonEtAl.XYZ",
"approx.scotopic.luminance.LarsonEtAl.XYZ.array",
"approx.scotopic.luminance.LarsonEtAl.RGB",
"approx.scotopic.luminance.LarsonEtAl.RGB.array",
"XYZ2scotopic.Rawtran",
"XYZ2scotopic.Rawtran.array",
"effectivePupilArea",
"luminance2troland",
"illuminance2troland",
"VKSgraphic",
"VKSvariantGraphic",
"showDuplicated",
"calculateCircle",
"scoreFM100Graphic",
"interpretation.VingrysAndKingSmith",
"interpretation.Foutch",
"D15Foutch",
"calculateTES",
"scoreRoth28Graphic",
"scoreD15Graphic",
"scoreD15TCDS",
"lightAdaptedPupilSize.Holladay",
"lightAdaptedPupilSize.Crawford",
"lightAdaptedPupilSize.MoonAndSpencer",
"lightAdaptedPupilSize.DeGrootAndGebhard",
"lightAdaptedPupilSize.LeGrand",
"lightAdaptedPupilSize.StanleyAndDavies",
"lightAdaptedPupilSize.Barten",
"lightAdaptedPupilSize.BlackieAndHowland",
"lightAdaptedPupilSize.WinnEtAl",
"attenuationNumberOfEyes",
"effectiveCornealFluxDensity",
"lightAdaptedPupilSize.WatsonAndYellott",
"greyscale.avg",
"greyscale.Y",
"greyscale.Linear",
"greyscale.RMY",
"greyscale.BT709",
"greyscale.Luminosity",
"RGBtoHSL",
"Color.Vision.c2g",
"Color.Vision.Daltonize",
"Color.Vision.Simulate",
"Color.Vision.VingrysAndKingSmith",
"decolorize",
"decolorizeFile")

